rm(list=ls())
library(nlme)

## Calculate standard error
se <- function(x) sqrt(var(x)/length(x))

## Add error bars to a barplot
error.bar <- function(x, y, ebl, ebu = ebl, length = 0.03, ...)
  arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
         length = length, ...)

## Set lmeControl parameters for mixed effects models
lmec <- lmeControl(opt="optim", msMaxIter = 200, msMaxEval = 500, msVerbose = TRUE)

## Import chlorophyll data
chl <- read.csv("FEX chlorophyll.csv")
chl$id <- paste(chl$IS,chl$treat)
id <- sort(unique(chl$id))
data <- NULL

## Loop to subtract mean before values from each after value
for(i in 1:length(id)){
  aft <- chl[chl$id==id[i] & chl$time=="After",]
  bef <- chl[chl$id==id[i] & chl$time=="Before",]
  x.bef <- mean(bef$chlorophyll)
  for(j in 1:5){
    sub.aft <- aft[aft$rep==j,]
    dat <- data.frame(IS=sub.aft$IS[1], temp=sub.aft$temp[1], treat=sub.aft$treat[1], rep=sub.aft$rep[1], chlorophyll=sub.aft$chlorophyll-x.bef)
    data <- rbind(data, dat)
  }
}

## Analysis and visualisation
m1.chl <- lme(chlorophyll ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.chl <- lme(chlorophyll ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.chl <- lme(chlorophyll ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.chl <- lme(chlorophyll ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.chl <- AIC(m1.chl,m2.chl,m3.chl,m4.chl); aic.chl[2]-min(aic.chl[2])
anova(m.chl <- lme(chlorophyll ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec))
effect.chl <- data.frame(aggregate(chlorophyll ~ temp * treat, data=data, mean), se=aggregate(chlorophyll ~ temp * treat, data=data, se)$chlorophyll)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.chl, type="normalized")); qqline(resid(m.chl, type="normalized"))
plot(fitted(m.chl), resid(m.chl, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.chl, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.chl, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S4 in the paper
tiff("FEX chlorophyll.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.chl$chlorophyll, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.chl$chlorophyll-effect.chl$se),max(effect.chl$chlorophyll+effect.chl$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.chl$chlorophyll, effect.chl$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~chlorophyll~concentration~(mg~m^-2)), side=2, line=2.5)
dev.off()
