rm(list=ls())
library(nlme)

## Calculate standard error
se <- function(x) sqrt(var(x)/length(x))

## Add error bars to a barplot
error.bar <- function(x, y, ebl, ebu = ebl, length = 0.03, ...)
  arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
         length = length, ...)

## Set lmeControl parameters for mixed effects models
lmec <- lmeControl(opt="optim", msMaxIter = 200, msMaxEval = 500, msVerbose = TRUE)

## Import decomposition data
decomp <- read.csv("FEX decomp.csv")
macro <- decomp[decomp$mesh=="Macroinvert",]
micro <- decomp[decomp$mesh=="Microbial",]

## Analysis and visualisation of invertebrate-mediated decomposition
m1.macro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, data=macro, control=lmec)
m2.macro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=macro, control=lmec)
m3.macro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=macro, control=lmec)
m4.macro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=macro, control=lmec)
aic.macro <- AIC(m1.macro,m2.macro,m3.macro,m4.macro); aic.macro[2]-min(aic.macro[2])
anova(m.macro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=macro, control=lmec))
effect.macro <- data.frame(aggregate(decomp ~ temp * treat, data=macro, mean), se=aggregate(decomp ~ temp * treat, data=macro, se)$decomp)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,2))
qqnorm(resid(m.macro, type="normalized")); qqline(resid(m.macro, type="normalized"))
plot(fitted(m.macro), resid(m.macro, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.macro, type="normalized") ~ macro$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.macro, type="normalized") ~ macro$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Analysis and visualisation of microbial decomposition
m1.micro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, data=micro, control=lmec)
m2.micro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=micro, control=lmec)
m3.micro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=micro, control=lmec)
m4.micro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=micro, control=lmec)
aic.micro <- AIC(m1.micro,m2.micro,m3.micro,m4.micro); aic.micro[2]-min(aic.micro[2])
anova(m.micro <- lme(decomp ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=micro, control=lmec))
effect.micro <- data.frame(aggregate(decomp ~ temp * treat, data=micro, mean), se=aggregate(decomp ~ temp * treat, data=micro, se)$decomp)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,2))
qqnorm(resid(m.micro, type="normalized")); qqline(resid(m.micro, type="normalized"))
plot(fitted(m.micro), resid(m.micro, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.micro, type="normalized") ~ micro$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.micro, type="normalized") ~ micro$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Figure 2 in the paper
tiff("FEX decomposition.tif",8.9,14.5,pointsize=11,units="cm",res=600,compression="lzw")
par(mfrow=c(2,1), oma=c(3.5,0,0,0), mar=c(0.5,5,1,1))
plot(effect.macro$decomp, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.macro$decomp-effect.macro$se),max(effect.macro$decomp+effect.macro$se)))
axis(1, c(1:4), labels=F)
error.bar(1:4, effect.macro$decomp, effect.macro$se)
abline(v=2.5, lty=2)
mtext(quote(Invertebrate-mediated), side=2, line=3.7, cex=1)
mtext(quote(decomposition~rate~"[mg"~day^-1*"]"), side=2, line=2.5)
mtext("a", side=3, line=0, adj=-0.37, font=2, cex=1.2)

plot(effect.micro$decomp, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.micro$decomp-effect.micro$se),max(effect.micro$decomp+effect.micro$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.micro$decomp, effect.micro$se)
abline(v=2.5, lty=2)
mtext(quote(Microbial), side=2, line=3.7, cex=1)
mtext(quote(decomposition~rate~"[mg"~day^-1*"]"), side=2, line=2.5)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext("b", side=3, line=0, adj=-0.37, font=2, cex=1.2)
dev.off()
