rm(list=ls())
library(nlme)

## Calculate standard error
se <- function(x) sqrt(var(x)/length(x))

## Add error bars to a barplot
error.bar <- function(x, y, ebl, ebu = ebl, length = 0.03, ...)
  arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
         length = length, ...)

## Set lmeControl parameters for mixed effects models
lmec <- lmeControl(opt="optim", msMaxIter = 200, msMaxEval = 500, msVerbose = TRUE)

## Import diatom mass-abundance data
mn <- read.csv("FEX diatoms.csv")
mn[mn$profile=="Nfixing","profile"] <- "motile"
mn$biomass <- mn$mass * mn$abundance
mn$id <- paste(mn$IS,mn$treat)
id <- sort(unique(mn$id))
sp <- sort(unique(mn$species))
profile <- sort(unique(mn$profile))
data <- NULL

## Loop to subtract mean before values from each after value
for(i in 1:length(id)){
  bef <- mn[mn$id==id[i] & mn$time=="Before",]
  bef.rep <- unique(bef$rep)
  M.bef <- N.bef <- B.bef <- rep(NA,length(bef.rep))
  for(j in 1:length(bef.rep)){
    sub.bef <- bef[bef$rep==bef.rep[j],]
    M.bef[j] <- sum(sub.bef$biomass)/sum(sub.bef$abundance)
    N.bef[j] <- sum(sub.bef$abundance)
    B.bef[j] <- sum(sub.bef$biomass)
  }
  aft <- mn[mn$id==id[i] & mn$time=="After",]
  aft.rep <- unique(aft$rep)
  for(j in 1:length(aft.rep)){
    sub.aft <- aft[aft$rep==aft.rep[j],]
    dat <- data.frame(IS=sub.aft$IS[1], temp=sub.aft$temp[1], treat=sub.aft$treat[1], rep=sub.aft$rep[1],
                      mass=sum(sub.aft$biomass)/sum(sub.aft$abundance) - mean(M.bef),
                      abundance=sum(sub.aft$abundance) - mean(N.bef), biomass=sum(sub.aft$biomass) - mean(B.bef))
    data <- rbind(data, dat)
  }
}

## Analysis and visualisation of total diatom biomass
m1.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.biomass <- AIC(m1.biomass,m2.biomass,m3.biomass,m4.biomass); aic.biomass[2]-min(aic.biomass[2])
anova(m.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec))
effect.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=data, mean), se=aggregate(biomass ~ temp * treat, data=data, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.biomass, type="normalized")); qqline(resid(m.biomass, type="normalized"))
plot(fitted(m.biomass), resid(m.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.biomass, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.biomass, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Figure 1b in the paper
tiff("FEX diatom biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.biomass$biomass-effect.biomass$se),max(effect.biomass$biomass+effect.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.biomass$biomass, effect.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Motile diatom group analysis
motile <- NULL

for(i in 1:length(id)){
  bef.motile <- mn[mn$id==id[i] & mn$time=="Before" & mn$profile=="motile",]
  bef.motile.rep <- unique(bef.motile$rep)
  M.bef.motile <- N.bef.motile <- B.bef.motile <- rep(NA,length(bef.motile.rep))
  for(j in 1:length(bef.motile.rep)){
    sub.bef.motile <- bef.motile[bef.motile$rep==bef.motile.rep[j],]
    M.bef.motile[j] <- sum(sub.bef.motile$biomass)/sum(sub.bef.motile$abundance)
    N.bef.motile[j] <- sum(sub.bef.motile$abundance)
    B.bef.motile[j] <- sum(sub.bef.motile$biomass)
  }
  aft.motile <- mn[mn$id==id[i] & mn$time=="After" & mn$profile=="motile",]
  aft.rep.motile <- unique(aft.motile$rep)
  for(j in 1:length(aft.rep.motile)){
    sub.aft.motile <- aft.motile[aft.motile$rep==aft.rep.motile[j],]
    dat.motile <- data.frame(IS=sub.aft.motile$IS[1], temp=sub.aft.motile$temp[1], treat=sub.aft.motile$treat[1], rep=sub.aft.motile$rep[1],
                             mass=sum(sub.aft.motile$biomass)/sum(sub.aft.motile$abundance) - mean(M.bef.motile),
                             abundance=sum(sub.aft.motile$abundance) - mean(N.bef.motile), biomass=sum(sub.aft.motile$biomass) - mean(B.bef.motile))
    motile <- rbind(motile, dat.motile)
  }
}

## Analysis and visualisation of motile diatom biomass
m1.motile.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=motile, control=lmec)
m2.motile.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=motile, control=lmec)
m3.motile.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=motile, control=lmec)
m4.motile.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=motile, control=lmec)
aic.motile.biomass <- AIC(m1.motile.biomass,m2.motile.biomass,m3.motile.biomass,m4.motile.biomass); aic.motile.biomass[2]-min(aic.motile.biomass[2])
anova(m.motile.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=motile, control=lmec))
effect.motile.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=motile, mean), se=aggregate(biomass ~ temp * treat, data=motile, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.motile.biomass, type="normalized")); qqline(resid(m.motile.biomass, type="normalized"))
plot(fitted(m.motile.biomass), resid(m.motile.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.motile.biomass, type="normalized") ~ motile$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.motile.biomass, type="normalized") ~ motile$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3d in the paper
tiff("FEX motile biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.motile.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.motile.biomass$biomass-effect.motile.biomass$se),max(effect.motile.biomass$biomass+effect.motile.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.motile.biomass$biomass, effect.motile.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## High profile diatom group analysis
high <- NULL

for(i in 1:length(id)){
  bef.high <- mn[mn$id==id[i] & mn$time=="Before" & mn$profile=="high",]
  bef.high.rep <- unique(bef.high$rep)
  M.bef.high <- N.bef.high <- B.bef.high <- rep(NA,length(bef.high.rep))
  for(j in 1:length(bef.high.rep)){
    sub.bef.high <- bef.high[bef.high$rep==bef.high.rep[j],]
    M.bef.high[j] <- sum(sub.bef.high$biomass)/sum(sub.bef.high$abundance)
    N.bef.high[j] <- sum(sub.bef.high$abundance)
    B.bef.high[j] <- sum(sub.bef.high$biomass)
  }
  aft.high <- mn[mn$id==id[i] & mn$time=="After" & mn$profile=="high",]
  aft.rep.high <- unique(aft.high$rep)
  for(j in 1:length(aft.rep.high)){
    sub.aft.high <- aft.high[aft.high$rep==aft.rep.high[j],]
    dat.high <- data.frame(IS=sub.aft.high$IS[1], temp=sub.aft.high$temp[1], treat=sub.aft.high$treat[1], rep=sub.aft.high$rep[1],
                           mass=sum(sub.aft.high$biomass)/sum(sub.aft.high$abundance) - mean(M.bef.high),
                           abundance=sum(sub.aft.high$abundance) - mean(N.bef.high), biomass=sum(sub.aft.high$biomass) - mean(B.bef.high))
    high <- rbind(high, dat.high)
  }
}

## Analysis and visualisation of high profile diatom biomass
m1.high.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=high, control=lmec)
m2.high.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=high, control=lmec)
m3.high.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=high, control=lmec)
m4.high.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=high, control=lmec)
aic.high.biomass <- AIC(m1.high.biomass,m2.high.biomass,m3.high.biomass,m4.high.biomass); aic.high.biomass[2]-min(aic.high.biomass[2])
anova(m.high.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=high, control=lmec))
effect.high.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=high, mean), se=aggregate(biomass ~ temp * treat, data=high, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.high.biomass, type="normalized")); qqline(resid(m.high.biomass, type="normalized"))
plot(fitted(m.high.biomass), resid(m.high.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.high.biomass, type="normalized") ~ high$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.high.biomass, type="normalized") ~ high$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3e in the paper
tiff("FEX high profile biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.high.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.high.biomass$biomass-effect.high.biomass$se),max(effect.high.biomass$biomass+effect.high.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.high.biomass$biomass, effect.high.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Low profile diatom group analysis
low <- NULL

for(i in 1:length(id)){
  bef.low <- mn[mn$id==id[i] & mn$time=="Before" & mn$profile=="low",]
  bef.low.rep <- unique(bef.low$rep)
  M.bef.low <- N.bef.low <- B.bef.low <- rep(NA,length(bef.low.rep))
  for(j in 1:length(bef.low.rep)){
    sub.bef.low <- bef.low[bef.low$rep==bef.low.rep[j],]
    M.bef.low[j] <- sum(sub.bef.low$biomass)/sum(sub.bef.low$abundance)
    N.bef.low[j] <- sum(sub.bef.low$abundance)
    B.bef.low[j] <- sum(sub.bef.low$biomass)
  }
  aft.low <- mn[mn$id==id[i] & mn$time=="After" & mn$profile=="low",]
  aft.rep.low <- unique(aft.low$rep)
  for(j in 1:length(aft.rep.low)){
    sub.aft.low <- aft.low[aft.low$rep==aft.rep.low[j],]
    dat.low <- data.frame(IS=sub.aft.low$IS[1], temp=sub.aft.low$temp[1], treat=sub.aft.low$treat[1], rep=sub.aft.low$rep[1],
                           mass=sum(sub.aft.low$biomass)/sum(sub.aft.low$abundance) - mean(M.bef.low),
                           abundance=sum(sub.aft.low$abundance) - mean(N.bef.low), biomass=sum(sub.aft.low$biomass) - mean(B.bef.low))
    low <- rbind(low, dat.low)
  }
}

## Analysis and visualisation of low profile diatom biomass
m1.low.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=low, control=lmec)
m2.low.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=low, control=lmec)
m3.low.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=low, control=lmec)
m4.low.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=low, control=lmec)
aic.low.biomass <- AIC(m1.low.biomass,m2.low.biomass,m3.low.biomass,m4.low.biomass); aic.low.biomass[2]-min(aic.low.biomass[2])
anova(m.low.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=low, control=lmec))
effect.low.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=low, mean), se=aggregate(biomass ~ temp * treat, data=low, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.low.biomass, type="normalized")); qqline(resid(m.low.biomass, type="normalized"))
plot(fitted(m.low.biomass), resid(m.low.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.low.biomass, type="normalized") ~ low$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.low.biomass, type="normalized") ~ low$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3f in the paper
tiff("FEX low profile biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.low.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.low.biomass$biomass-effect.low.biomass$se),max(effect.low.biomass$biomass+effect.low.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.low.biomass$biomass, effect.low.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()
