rm(list=ls())
library(cheddar); library(nlme)

## Calculate standard error
se <- function(x) sqrt(var(x)/length(x))

## Add error bars to a barplot
error.bar <- function(x, y, ebl, ebu = ebl, length = 0.03, ...)
  arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
         length = length, ...)

## Set lmeControl parameters for mixed effects models
lmec <- lmeControl(opt="optim", msMaxIter = 200, msMaxEval = 500, msVerbose = TRUE)

## Import food web data in cheddar format
IS <- LoadCollection("Food web")
info <- CollectionCPS(IS, c('title','temp','IS'))
temp <- sort(info$temp)
IS <- IS[info$title[order(info$temp)]]

## Food web properties
stat <- CollectionCPS(IS, c(IS='IS', temp='temp', time='time', treat='treat', rep='rep', C='DirectedConnectance'))
stat$MTL <- apply(as.matrix(CollectionCPS(IS, c('ShortWeightedTrophicLevel'))), 1, mean, na.rm=T)

for(i in 1:length(IS)){
  con <- unique(TLPS(IS[[i]])$consumer)
  res <- unique(TLPS(IS[[i]])$resource)
  stat[i,"CRR"] <- length(con)/length(res)
}

## Loop to subtract mean before values from each after value
stat$id <- paste(stat$IS,stat$treat)
id <- sort(unique(stat$id))
data <- NULL

for(i in 1:length(id)){
  bef <- stat[stat$id==id[i] & stat$time=="Before",]
  xbef <- colMeans(bef[6:(length(bef)-1)])
  aft <- stat[stat$id==id[i] & stat$time=="After",]
  for(j in 1:length(aft[,1])){
    aft[j,6:(length(bef)-1)] <- aft[j,6:(length(bef)-1)] - xbef
  }
  data <- rbind(data, aft)
}
data <- data[,!(names(data) %in% c("time","id"))]
data$temp <- c("warm","warm","warm","cold","cold","cold")[match(data$IS,c(3,6,9,11,13,14))]

## Analysis and visualisation of connectance
m1.C <- lme(C ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.C <- lme(C ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.C <- lme(C ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.C <- lme(C ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.C <- AIC(m1.C,m2.C,m3.C,m4.C); aic.C[2]-min(aic.C[2])
anova(m.C <- lme(C ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec))
effect.C <- data.frame(aggregate(C ~ temp * treat, data=data, mean), se=aggregate(C ~ temp * treat, data=data, se)$C)

par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.C, type="normalized")); qqline(resid(m.C, type="normalized"))
plot(fitted(m.C), resid(m.C, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.C, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.C, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Mean trophic level
m1.MTL <- lme(MTL ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.MTL <- lme(MTL ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.MTL <- lme(MTL ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.MTL <- lme(MTL ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.MTL <- AIC(m1.MTL,m2.MTL,m3.MTL,m4.MTL); aic.MTL[2]-min(aic.MTL[2])
anova(m.MTL <- lme(MTL ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec))
effect.MTL <- data.frame(aggregate(MTL ~ temp * treat, data=data, mean), se=aggregate(MTL ~ temp * treat, data=data, se)$MTL)

par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.MTL, type="normalized")); qqline(resid(m.MTL, type="normalized"))
plot(fitted(m.MTL), resid(m.MTL, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.MTL, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.MTL, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Consumer-resource ratio
m1.CRR <- lme(CRR ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.CRR <- lme(CRR ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.CRR <- lme(CRR ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.CRR <- lme(CRR ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.CRR <- AIC(m1.CRR,m2.CRR,m3.CRR,m4.CRR); aic.CRR[2]-min(aic.CRR[2])
anova(m.CRR <- lme(CRR ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec))
effect.CRR <- data.frame(aggregate(CRR ~ temp * treat, data=data, mean), se=aggregate(CRR ~ temp * treat, data=data, se)$CRR)

par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.CRR, type="normalized")); qqline(resid(m.CRR, type="normalized"))
plot(fitted(m.CRR), resid(m.CRR, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.CRR, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.CRR, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Figure 3a-b in the paper
tiff("Food webs.tif",8,16,pointsize=10,units="cm",res=600,compression="lzw")
par(mfrow=c(2,1), mar=c(2,3,0,0))
PlotWebByLevel(IS[["13 After Fish 5"]], main="", level="ShortWeightedTrophicLevel", pch=21, cex=1.5, bg="dodgerblue", ylim=c(1,3.1), highlight.nodes=F)
mtext("Trophic level", side=2, line=2, adj=0.5)
mtext("Food web for a Cold-Fish treatment", side=1, line=0.5, adj=0.5)

PlotWebByLevel(IS[["6 After Fish 4"]], main="", level="ShortWeightedTrophicLevel", pch=21, cex=1.5, bg="firebrick", ylim=c(1,3.1), highlight.nodes=F)
mtext("Trophic level", side=2, line=2, adj=0.5)
mtext("Food web for a Warm-Fish treatment", side=1, line=0.5, adj=0.5)
dev.off()

## Figure 3c-e in the paper
tiff("Food web metrics.tif",8,20,pointsize=18,units="cm",res=600,compression="lzw")
par(mfrow=c(3,1), oma=c(3.5,0.5,0.5,0.5), mar=c(0.5,3.5,0.5,0.5))
plot(effect.C$C, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.C$C-effect.C$se),max(effect.C$C+effect.C$se)))
axis(1, c(1:4), labels=F)
error.bar(1:4, effect.C$C, effect.C$se)
abline(v=2.5, lty=2)
mtext(quote(Delta~connectance), side=2, line=2.5, cex=0.7)

plot(effect.MTL$MTL, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.MTL$MTL-effect.MTL$se),max(effect.MTL$MTL+effect.MTL$se)))
axis(1, c(1:4), labels=F)
error.bar(1:4, effect.MTL$MTL, effect.MTL$se)
abline(v=2.5, lty=2)
mtext(quote(Delta~mean~trophic~level), side=2, line=2.5, cex=0.7)

plot(effect.CRR$CRR, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.CRR$CRR-effect.CRR$se),max(effect.CRR$CRR+effect.CRR$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.CRR$CRR, effect.CRR$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5, cex=0.7)
mtext("No fish", side=1, line=2.5, at=3.5, cex=0.7)
mtext(quote(Delta~consumer-resource~ratio), side=2, line=2.5, cex=0.7)
dev.off()
