rm(list=ls())
library(nlme)

## Calculate standard error
se <- function(x) sqrt(var(x)/length(x))

## Add error bars to a barplot
error.bar <- function(x, y, ebl, ebu = ebl, length = 0.03, ...)
  arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
         length = length, ...)

## Set lmeControl parameters for mixed effects models
lmec <- lmeControl(opt="optim", msMaxIter = 200, msMaxEval = 500, msVerbose = TRUE)

## Import invertebrate mass-abundance data
mn <- read.csv("FEX inverts.csv")
mn$biomass <- mn$mass * mn$abundance
mn$id <- paste(mn$IS,mn$treat)
id <- sort(unique(mn$id))
sp <- sort(unique(mn$species))
data <- NULL

## Loop to subtract mean before values from each after value
for(i in 1:length(id)){
  bef <- mn[mn$id==id[i] & mn$time=="Before",]
  M.bef <- N.bef <- B.bef <- rep(NA,5)
  for(j in 1:5){
    sub.bef <- bef[bef$rep==j,]
    M.bef[j] <- sum(sub.bef$biomass)/sum(sub.bef$abundance)
    N.bef[j] <- sum(sub.bef$abundance)
    B.bef[j] <- sum(sub.bef$biomass)
  }
  aft <- mn[mn$id==id[i] & mn$time=="After",]
  for(j in 1:5){
    sub.aft <- aft[aft$rep==j,]
    dat <- data.frame(IS=sub.aft$IS[1], temp=sub.aft$temp[1], treat=sub.aft$treat[1], rep=sub.aft$rep[1],
                      mass=sum(sub.aft$biomass)/sum(sub.aft$abundance) - mean(M.bef),
                      abundance=sum(sub.aft$abundance) - mean(N.bef), biomass=sum(sub.aft$biomass) - mean(B.bef))
    data <- rbind(data, dat)
  }
}

## Analysis and visualisation of total invertebrate biomass
m1.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=data, control=lmec)
m2.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec)
m3.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=data, control=lmec)
m4.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=data, control=lmec)
aic.biomass <- AIC(m1.biomass,m2.biomass,m3.biomass,m4.biomass); aic.biomass[2]-min(aic.biomass[2])
anova(m.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=data, control=lmec))
effect.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=data, mean), se=aggregate(biomass ~ temp * treat, data=data, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.biomass, type="normalized")); qqline(resid(m.biomass, type="normalized"))
plot(fitted(m.biomass), resid(m.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.biomass, type="normalized") ~ data$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.biomass, type="normalized") ~ data$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Figure 1a in the paper
tiff("FEX invert biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.biomass$biomass-effect.biomass$se),max(effect.biomass$biomass+effect.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.biomass$biomass, effect.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Diamesa zernyi analysis
diaz <- NULL

for(i in 1:length(id)){
  aft.diaz <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Diamesa zernyi",]
  bef.diaz <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Diamesa zernyi",]
  M.bef.diaz <- mean(bef.diaz$mass); N.bef.diaz <- sum(bef.diaz$abundance)/5; B.bef.diaz <- sum(bef.diaz$biomass)/5
  if(length(aft.diaz$IS)==0 & length(bef.diaz$IS)>0) aft.diaz <- data.frame(bef.diaz[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.diaz)==T) N.bef.diaz <- B.bef.diaz <- 0
  diaz <- rbind(diaz, data.frame(aft.diaz[,c("IS","temp","treat","rep")], mass=aft.diaz$mass-M.bef.diaz, abundance=aft.diaz$abundance-N.bef.diaz, biomass=aft.diaz$biomass-B.bef.diaz))
}

## Analysis and visualisation of Diamesa zernyi biomass
m1.diaz.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=diaz, control=lmec)
m2.diaz.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=diaz, control=lmec)
m3.diaz.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=diaz, control=lmec)
m4.diaz.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=diaz, control=lmec)
aic.diaz.biomass <- AIC(m1.diaz.biomass,m2.diaz.biomass,m3.diaz.biomass,m4.diaz.biomass); aic.diaz.biomass[2]-min(aic.diaz.biomass[2])
anova(m.diaz.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=diaz, control=lmec))
effect.diaz.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=diaz, mean), se=aggregate(biomass ~ temp * treat, data=diaz, se)$biomass)
effect.diaz.biomass$se[is.na(effect.diaz.biomass$se)] <- 0

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.diaz.biomass, type="normalized")); qqline(resid(m.diaz.biomass, type="normalized"))
plot(fitted(m.diaz.biomass), resid(m.diaz.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.diaz.biomass, type="normalized") ~ diaz$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.diaz.biomass, type="normalized") ~ diaz$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.diaz.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.diaz.biomass$biomass-effect.diaz.biomass$se),max(effect.diaz.biomass$biomass+effect.diaz.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.diaz.biomass$biomass, effect.diaz.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Dicranota exclusa
dice <- NULL

for(i in 1:length(id)){
  aft.dice <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Dicranota exclusa",]
  bef.dice <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Dicranota exclusa",]
  M.bef.dice <- mean(bef.dice$mass); N.bef.dice <- sum(bef.dice$abundance)/5; B.bef.dice <- sum(bef.dice$biomass)/5
  if(length(aft.dice$IS)==0 & length(bef.dice$IS)>0) aft.dice <- data.frame(bef.dice[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.dice)==T) N.bef.dice <- B.bef.dice <- 0
  dice <- rbind(dice, data.frame(aft.dice[,c("IS","temp","treat","rep")], mass=aft.dice$mass-M.bef.dice, abundance=aft.dice$abundance-N.bef.dice, biomass=aft.dice$biomass-B.bef.dice))
}

## Analysis and visualisation of Dicranota exclusa biomass
m1.dice.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=dice, control=lmec)
m2.dice.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=dice, control=lmec)
m3.dice.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=dice, control=lmec)
m4.dice.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=dice, control=lmec)
aic.dice.biomass <- AIC(m1.dice.biomass,m2.dice.biomass,m3.dice.biomass,m4.dice.biomass); aic.dice.biomass[2]-min(aic.dice.biomass[2])
anova(m.dice.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=dice, control=lmec))
effect.dice.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=dice, mean), se=aggregate(biomass ~ temp * treat, data=dice, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.dice.biomass, type="normalized")); qqline(resid(m.dice.biomass, type="normalized"))
plot(fitted(m.dice.biomass), resid(m.dice.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.dice.biomass, type="normalized") ~ dice$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.dice.biomass, type="normalized") ~ dice$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.dice.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.dice.biomass$biomass-effect.dice.biomass$se),max(effect.dice.biomass$biomass+effect.dice.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.dice.biomass$biomass, effect.dice.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Eukiefferiella claripennis analysis
ecla <- NULL

for(i in 1:length(id)){
  aft.ecla <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Eukiefferiella claripennis",]
  bef.ecla <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Eukiefferiella claripennis",]
  M.bef.ecla <- mean(bef.ecla$mass); N.bef.ecla <- sum(bef.ecla$abundance)/5; B.bef.ecla <- sum(bef.ecla$biomass)/5
  if(length(aft.ecla$IS)==0 & length(bef.ecla$IS)>0) aft.ecla <- data.frame(bef.ecla[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.ecla)==T) N.bef.ecla <- B.bef.ecla <- 0
  ecla <- rbind(ecla, data.frame(aft.ecla[,c("IS","temp","treat","rep")], mass=aft.ecla$mass-M.bef.ecla, abundance=aft.ecla$abundance-N.bef.ecla, biomass=aft.ecla$biomass-B.bef.ecla))
}

## Analysis and visualisation of Eukiefferiella claripennis biomass
m1.ecla.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=ecla, control=lmec)
m2.ecla.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=ecla, control=lmec)
m3.ecla.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=ecla, control=lmec)
m4.ecla.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=ecla, control=lmec)
aic.ecla.biomass <- AIC(m1.ecla.biomass,m2.ecla.biomass,m3.ecla.biomass,m4.ecla.biomass); aic.ecla.biomass[2]-min(aic.ecla.biomass[2])
anova(m.ecla.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=ecla, control=lmec))
effect.ecla.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=ecla, mean), se=aggregate(biomass ~ temp * treat, data=ecla, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.ecla.biomass, type="normalized")); qqline(resid(m.ecla.biomass, type="normalized"))
plot(fitted(m.ecla.biomass), resid(m.ecla.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.ecla.biomass, type="normalized") ~ ecla$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.ecla.biomass, type="normalized") ~ ecla$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.ecla.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.ecla.biomass$biomass-effect.ecla.biomass$se),max(effect.ecla.biomass$biomass+effect.ecla.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.ecla.biomass$biomass, effect.ecla.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Eukiefferiella minor analysis
emin <- NULL

for(i in 1:length(id)){
  aft.emin <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Eukiefferiella minor",]
  bef.emin <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Eukiefferiella minor",]
  M.bef.emin <- mean(bef.emin$mass); N.bef.emin <- sum(bef.emin$abundance)/5; B.bef.emin <- sum(bef.emin$biomass)/5
  if(length(aft.emin$IS)==0 & length(bef.emin$IS)>0) aft.emin <- data.frame(bef.emin[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.emin)==T) N.bef.emin <- B.bef.emin <- 0
  emin <- rbind(emin, data.frame(aft.emin[,c("IS","temp","treat","rep")], mass=aft.emin$mass-M.bef.emin, abundance=aft.emin$abundance-N.bef.emin, biomass=aft.emin$biomass-B.bef.emin))
}

## Analysis and visualisation of Eukiefferiella minor biomass
m1.emin.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=emin, control=lmec)
m2.emin.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=emin, control=lmec)
m3.emin.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=emin, control=lmec)
m4.emin.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=emin, control=lmec)
aic.emin.biomass <- AIC(m1.emin.biomass,m2.emin.biomass,m3.emin.biomass,m4.emin.biomass); aic.emin.biomass[2]-min(aic.emin.biomass[2])
anova(m.emin.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=emin, control=lmec))
effect.emin.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=emin, mean), se=aggregate(biomass ~ temp * treat, data=emin, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.emin.biomass, type="normalized")); qqline(resid(m.emin.biomass, type="normalized"))
plot(fitted(m.emin.biomass), resid(m.emin.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.emin.biomass, type="normalized") ~ emin$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.emin.biomass, type="normalized") ~ emin$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.emin.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.emin.biomass$biomass-effect.emin.biomass$se),max(effect.emin.biomass$biomass+effect.emin.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.emin.biomass$biomass, effect.emin.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Limnophora riparia analysis
lrip <- NULL

for(i in 1:length(id)){
  aft.lrip <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Limnophora riparia",]
  bef.lrip <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Limnophora riparia",]
  M.bef.lrip <- mean(bef.lrip$mass); N.bef.lrip <- sum(bef.lrip$abundance)/5; B.bef.lrip <- sum(bef.lrip$biomass)/5
  if(length(aft.lrip$IS)==0 & length(bef.lrip$IS)>0) aft.lrip <- data.frame(bef.lrip[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.lrip)==T) N.bef.lrip <- B.bef.lrip <- 0
  lrip <- rbind(lrip, data.frame(aft.lrip[,c("IS","temp","treat","rep")], mass=aft.lrip$mass-M.bef.lrip, abundance=aft.lrip$abundance-N.bef.lrip, biomass=aft.lrip$biomass-B.bef.lrip))
}

## Analysis and visualisation of Limnophora riparia biomass
m1.lrip.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=lrip, control=lmec)
m2.lrip.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=lrip, control=lmec)
m3.lrip.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=lrip, control=lmec)
m4.lrip.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=lrip, control=lmec)
aic.lrip.biomass <- AIC(m1.lrip.biomass,m2.lrip.biomass,m3.lrip.biomass,m4.lrip.biomass); aic.lrip.biomass[2]-min(aic.lrip.biomass[2])
anova(m.lrip.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=lrip, control=lmec))
effect.lrip.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=lrip, mean), se=aggregate(biomass ~ temp * treat, data=lrip, se)$biomass)
effect.lrip.biomass$se[is.na(effect.lrip.biomass$se)] <- 0

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.lrip.biomass, type="normalized")); qqline(resid(m.lrip.biomass, type="normalized"))
plot(fitted(m.lrip.biomass), resid(m.lrip.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.lrip.biomass, type="normalized") ~ lrip$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.lrip.biomass, type="normalized") ~ lrip$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.lrip.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.lrip.biomass$biomass-effect.lrip.biomass$se),max(effect.lrip.biomass$biomass+effect.lrip.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.lrip.biomass$biomass, effect.lrip.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Metriocnemus sp. B
metb <- NULL

for(i in 1:length(id)){
  aft.metb <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Metriocnemus sp. B",]
  bef.metb <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Metriocnemus sp. B",]
  M.bef.metb <- mean(bef.metb$mass); N.bef.metb <- sum(bef.metb$abundance)/5; B.bef.metb <- sum(bef.metb$biomass)/5
  if(length(aft.metb$IS)==0 & length(bef.metb$IS)>0) aft.metb <- data.frame(bef.metb[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.metb)==T) N.bef.metb <- B.bef.metb <- 0
  metb <- rbind(metb, data.frame(aft.metb[,c("IS","temp","treat","rep")], mass=aft.metb$mass-M.bef.metb, abundance=aft.metb$abundance-N.bef.metb, biomass=aft.metb$biomass-B.bef.metb))
}

## Analysis and visualisation of Metriocnemus sp. B biomass
m1.metb.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=metb, control=lmec)
m2.metb.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=metb, control=lmec)
m3.metb.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=metb, control=lmec)
m4.metb.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=metb, control=lmec)
aic.metb.biomass <- AIC(m1.metb.biomass,m2.metb.biomass,m3.metb.biomass,m4.metb.biomass); aic.metb.biomass[2]-min(aic.metb.biomass[2])
anova(m.metb.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=metb, control=lmec))
effect.metb.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=metb, mean), se=aggregate(biomass ~ temp * treat, data=metb, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.metb.biomass, type="normalized")); qqline(resid(m.metb.biomass, type="normalized"))
plot(fitted(m.metb.biomass), resid(m.metb.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.metb.biomass, type="normalized") ~ metb$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.metb.biomass, type="normalized") ~ metb$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Visualisation of biomass patterns
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.metb.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.metb.biomass$biomass-effect.metb.biomass$se),max(effect.metb.biomass$biomass+effect.metb.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.metb.biomass$biomass, effect.metb.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Micropsectra atrofasciata analysis
mica <- NULL

for(i in 1:length(id)){
  aft.mica <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Micropsectra atrofasciata",]
  bef.mica <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Micropsectra atrofasciata",]
  M.bef.mica <- mean(bef.mica$mass); N.bef.mica <- sum(bef.mica$abundance)/5; B.bef.mica <- sum(bef.mica$biomass)/5
  if(length(aft.mica$IS)==0 & length(bef.mica$IS)>0) aft.mica <- data.frame(bef.mica[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.mica)==T) N.bef.mica <- B.bef.mica <- 0
  mica <- rbind(mica, data.frame(aft.mica[,c("IS","temp","treat","rep")], mass=aft.mica$mass-M.bef.mica, abundance=aft.mica$abundance-N.bef.mica, biomass=aft.mica$biomass-B.bef.mica))
}

## Analysis and visualisation of Micropsectra atrofasciata biomass
m1.mica.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=mica, control=lmec)
m2.mica.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=mica, control=lmec)
m3.mica.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=mica, control=lmec)
m4.mica.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=mica, control=lmec)
aic.mica.biomass <- AIC(m1.mica.biomass,m2.mica.biomass,m3.mica.biomass,m4.mica.biomass); aic.mica.biomass[2]-min(aic.mica.biomass[2])
anova(m.mica.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=mica, control=lmec))
effect.mica.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=mica, mean), se=aggregate(biomass ~ temp * treat, data=mica, se)$biomass)
effect.mica.biomass$se[is.na(effect.mica.biomass$se)] <- 0

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.mica.biomass, type="normalized")); qqline(resid(m.mica.biomass, type="normalized"))
plot(fitted(m.mica.biomass), resid(m.mica.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.mica.biomass, type="normalized") ~ mica$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.mica.biomass, type="normalized") ~ mica$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.mica.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.mica.biomass$biomass-effect.mica.biomass$se),max(effect.mica.biomass$biomass+effect.mica.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.mica.biomass$biomass, effect.mica.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Oligochaeta indet. analysis
olig <- NULL

for(i in 1:length(id)){
  aft.olig <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Oligochaeta indet.",]
  bef.olig <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Oligochaeta indet.",]
  M.bef.olig <- mean(bef.olig$mass); N.bef.olig <- sum(bef.olig$abundance)/5; B.bef.olig <- sum(bef.olig$biomass)/5
  if(length(aft.olig$IS)==0 & length(bef.olig$IS)>0) aft.olig <- data.frame(bef.olig[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.olig)==T) N.bef.olig <- B.bef.olig <- 0
  olig <- rbind(olig, data.frame(aft.olig[,c("IS","temp","treat","rep")], mass=aft.olig$mass-M.bef.olig, abundance=aft.olig$abundance-N.bef.olig, biomass=aft.olig$biomass-B.bef.olig))
}

## Analysis and visualisation of Oligochaeta indet. biomass
m1.olig.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=olig, control=lmec)
m2.olig.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=olig, control=lmec)
m3.olig.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=olig, control=lmec)
m4.olig.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=olig, control=lmec)
aic.olig.biomass <- AIC(m1.olig.biomass,m2.olig.biomass,m3.olig.biomass,m4.olig.biomass); aic.olig.biomass[2]-min(aic.olig.biomass[2])
anova(m.olig.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=olig, control=lmec))
effect.olig.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=olig, mean), se=aggregate(biomass ~ temp * treat, data=olig, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.olig.biomass, type="normalized")); qqline(resid(m.olig.biomass, type="normalized"))
plot(fitted(m.olig.biomass), resid(m.olig.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.olig.biomass, type="normalized") ~ olig$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.olig.biomass, type="normalized") ~ olig$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.olig.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.olig.biomass$biomass-effect.olig.biomass$se),max(effect.olig.biomass$biomass+effect.olig.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.olig.biomass$biomass, effect.olig.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Radix balthica analysis
rbal <- NULL

for(i in 1:length(id)){
  aft.rbal <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Radix balthica",]
  bef.rbal <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Radix balthica",]
  M.bef.rbal <- mean(bef.rbal$mass); N.bef.rbal <- sum(bef.rbal$abundance)/5; B.bef.rbal <- sum(bef.rbal$biomass)/5
  if(length(aft.rbal$IS)==0 & length(bef.rbal$IS)>0) aft.rbal <- data.frame(bef.rbal[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.rbal)==T) N.bef.rbal <- B.bef.rbal <- 0
  rbal <- rbind(rbal, data.frame(aft.rbal[,c("IS","temp","treat","rep")], mass=aft.rbal$mass-M.bef.rbal, abundance=aft.rbal$abundance-N.bef.rbal, biomass=aft.rbal$biomass-B.bef.rbal))
}

## Analysis and visualisation of Radix balthica biomass
m1.rbal.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=rbal, control=lmec)
m2.rbal.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=rbal, control=lmec)
m3.rbal.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=rbal, control=lmec)
m4.rbal.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=rbal, control=lmec)
aic.rbal.biomass <- AIC(m1.rbal.biomass,m2.rbal.biomass,m3.rbal.biomass,m4.rbal.biomass); aic.rbal.biomass[2]-min(aic.rbal.biomass[2])
anova(m.rbal.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=rbal, control=lmec))
effect.rbal.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=rbal, mean), se=aggregate(biomass ~ temp * treat, data=rbal, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.rbal.biomass, type="normalized")); qqline(resid(m.rbal.biomass, type="normalized"))
plot(fitted(m.rbal.biomass), resid(m.rbal.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.rbal.biomass, type="normalized") ~ rbal$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.rbal.biomass, type="normalized") ~ rbal$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3a in the paper
tiff("FEX Radix balthica biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.rbal.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.rbal.biomass$biomass-effect.rbal.biomass$se),max(effect.rbal.biomass$biomass+effect.rbal.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.rbal.biomass$biomass, effect.rbal.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Rheocricotopus effesus
rheo <- NULL

for(i in 1:length(id)){
  aft.rheo <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Rheocricotopus effesus",]
  bef.rheo <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Rheocricotopus effesus",]
  M.bef.rheo <- mean(bef.rheo$mass); N.bef.rheo <- sum(bef.rheo$abundance)/5; B.bef.rheo <- sum(bef.rheo$biomass)/5
  if(length(aft.rheo$IS)==0 & length(bef.rheo$IS)>0) aft.rheo <- data.frame(bef.rheo[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.rheo)==T) N.bef.rheo <- B.bef.rheo <- 0
  rheo <- rbind(rheo, data.frame(aft.rheo[,c("IS","temp","treat","rep")], mass=aft.rheo$mass-M.bef.rheo, abundance=aft.rheo$abundance-N.bef.rheo, biomass=aft.rheo$biomass-B.bef.rheo))
}

## Analysis and visualisation of Rheocricotopus effesus biomass
m1.rheo.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=rheo, control=lmec)
m2.rheo.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=rheo, control=lmec)
m3.rheo.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=rheo, control=lmec)
m4.rheo.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=rheo, control=lmec)
aic.rheo.biomass <- AIC(m1.rheo.biomass,m2.rheo.biomass,m3.rheo.biomass,m4.rheo.biomass); aic.rheo.biomass[2]-min(aic.rheo.biomass[2])
anova(m.rheo.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=rheo, control=lmec))
effect.rheo.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=rheo, mean), se=aggregate(biomass ~ temp * treat, data=rheo, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.rheo.biomass, type="normalized")); qqline(resid(m.rheo.biomass, type="normalized"))
plot(fitted(m.rheo.biomass), resid(m.rheo.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.rheo.biomass, type="normalized") ~ rheo$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.rheo.biomass, type="normalized") ~ rheo$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.rheo.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.rheo.biomass$biomass-effect.rheo.biomass$se),max(effect.rheo.biomass$biomass+effect.rheo.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.rheo.biomass$biomass, effect.rheo.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)


## Simulium aureum analysis
saur <- NULL

for(i in 1:length(id)){
  aft.saur <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Simulium aureum",]
  bef.saur <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Simulium aureum",]
  M.bef.saur <- mean(bef.saur$mass); N.bef.saur <- sum(bef.saur$abundance)/5; B.bef.saur <- sum(bef.saur$biomass)/5
  if(length(aft.saur$IS)==0 & length(bef.saur$IS)>0) aft.saur <- data.frame(bef.saur[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.saur)==T) N.bef.saur <- B.bef.saur <- 0
  saur <- rbind(saur, data.frame(aft.saur[,c("IS","temp","treat","rep")], mass=aft.saur$mass-M.bef.saur, abundance=aft.saur$abundance-N.bef.saur, biomass=aft.saur$biomass-B.bef.saur))
}

## Analysis and visualisation of Simulium aureum biomass
m1.saur.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=saur, control=lmec)
m2.saur.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=saur, control=lmec)
m3.saur.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=saur, control=lmec)
m4.saur.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=saur, control=lmec)
aic.saur.biomass <- AIC(m1.saur.biomass,m2.saur.biomass,m3.saur.biomass,m4.saur.biomass); aic.saur.biomass[2]-min(aic.saur.biomass[2])
anova(m.saur.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=saur, control=lmec))
effect.saur.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=saur, mean), se=aggregate(biomass ~ temp * treat, data=saur, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.saur.biomass, type="normalized")); qqline(resid(m.saur.biomass, type="normalized"))
plot(fitted(m.saur.biomass), resid(m.saur.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.saur.biomass, type="normalized") ~ saur$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.saur.biomass, type="normalized") ~ saur$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3b in the paper
tiff("FEX Simulium aureum biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.saur.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.saur.biomass$biomass-effect.saur.biomass$se),max(effect.saur.biomass$biomass+effect.saur.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.saur.biomass$biomass, effect.saur.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Simulium vittatum analysis
svit <- NULL

for(i in 1:length(id)){
  aft.svit <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Simulium vittatum",]
  bef.svit <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Simulium vittatum",]
  M.bef.svit <- mean(bef.svit$mass); N.bef.svit <- sum(bef.svit$abundance)/5; B.bef.svit <- sum(bef.svit$biomass)/5
  if(length(aft.svit$IS)==0 & length(bef.svit$IS)>0) aft.svit <- data.frame(bef.svit[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.svit)==T) N.bef.svit <- B.bef.svit <- 0
  svit <- rbind(svit, data.frame(aft.svit[,c("IS","temp","treat","rep")], mass=aft.svit$mass-M.bef.svit, abundance=aft.svit$abundance-N.bef.svit, biomass=aft.svit$biomass-B.bef.svit))
}

## Analysis and visualisation of Simulium vittatum biomass
m1.svit.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=svit, control=lmec)
m2.svit.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=svit, control=lmec)
m3.svit.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=svit, control=lmec)
m4.svit.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=svit, control=lmec)
aic.svit.biomass <- AIC(m1.svit.biomass,m2.svit.biomass,m3.svit.biomass,m4.svit.biomass); aic.svit.biomass[2]-min(aic.svit.biomass[2])
anova(m.svit.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=svit, control=lmec))
effect.svit.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=svit, mean), se=aggregate(biomass ~ temp * treat, data=svit, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.svit.biomass, type="normalized")); qqline(resid(m.svit.biomass, type="normalized"))
plot(fitted(m.svit.biomass), resid(m.svit.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.svit.biomass, type="normalized") ~ svit$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.svit.biomass, type="normalized") ~ svit$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

## Supplementary Figure S3c in the paper
tiff("FEX Simulium vittatum biomass.tif",12,12,units="cm",res=600,compression="lzw")
par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.svit.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.svit.biomass$biomass-effect.svit.biomass$se),max(effect.svit.biomass$biomass+effect.svit.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.svit.biomass$biomass, effect.svit.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
dev.off()


## Thienemanniella sp. analysis
thie <- NULL

for(i in 1:length(id)){
  aft.thie <- mn[mn$id==id[i] & mn$time=="After" & mn$species=="Thienemanniella sp.",]
  bef.thie <- mn[mn$id==id[i] & mn$time=="Before" & mn$species=="Thienemanniella sp.",]
  M.bef.thie <- mean(bef.thie$mass); N.bef.thie <- sum(bef.thie$abundance)/5; B.bef.thie <- sum(bef.thie$biomass)/5
  if(length(aft.thie$IS)==0 & length(bef.thie$IS)>0) aft.thie <- data.frame(bef.thie[,c("IS","temp","treat","rep")], mass=NA, abundance=0, biomass=0)[1,]
  if(is.na(N.bef.thie)==T) N.bef.thie <- B.bef.thie <- 0
  thie <- rbind(thie, data.frame(aft.thie[,c("IS","temp","treat","rep")], mass=aft.thie$mass-M.bef.thie, abundance=aft.thie$abundance-N.bef.thie, biomass=aft.thie$biomass-B.bef.thie))
}

## Analysis and visualisation of Thienemanniella sp. biomass
m1.thie.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, data=thie, control=lmec)
m2.thie.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp), data=thie, control=lmec)
m3.thie.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|treat), data=thie, control=lmec)
m4.thie.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=thie, control=lmec)
aic.thie.biomass <- AIC(m1.thie.biomass,m2.thie.biomass,m3.thie.biomass,m4.thie.biomass); aic.thie.biomass[2]-min(aic.thie.biomass[2])
anova(m.thie.biomass <- lme(biomass ~ temp * treat, random = ~ 1 | IS/rep, weights=varIdent(form=~1|temp*treat), data=thie, control=lmec))
effect.thie.biomass <- data.frame(aggregate(biomass ~ temp * treat, data=thie, mean), se=aggregate(biomass ~ temp * treat, data=thie, se)$biomass)

## Model validation
par(mfrow=c(2,2),mar=c(4,4,3,1))
qqnorm(resid(m.thie.biomass, type="normalized")); qqline(resid(m.thie.biomass, type="normalized"))
plot(fitted(m.thie.biomass), resid(m.thie.biomass, type="normalized"), main="Fitted v Residuals", xlab="Fitted values", ylab="Residuals"); abline(0,0)
boxplot(resid(m.thie.biomass, type="normalized") ~ thie$temp, main="Temperature v Residuals", ylab="Residuals"); abline(0,0)
boxplot(resid(m.thie.biomass, type="normalized") ~ thie$treat, main="Treatment v Residuals", ylab="Residuals"); abline(0,0)

par(mfrow=c(1,1), mar=c(4,4,1,1))
plot(effect.thie.biomass$biomass, pch=21, xlab="", ylab="", xaxt="n", cex=2, bg=c("dodgerblue","firebrick","dodgerblue","firebrick"),
     xlim=c(0.75,4.25), ylim=c(min(effect.thie.biomass$biomass-effect.thie.biomass$se),max(effect.thie.biomass$biomass+effect.thie.biomass$se)))
axis(1, c(1:4), c("Cold","Warm","Cold","Warm"))
error.bar(1:4, effect.thie.biomass$biomass, effect.thie.biomass$se)
abline(v=2.5, lty=2)
mtext("Fish", side=1, line=2.5, at=1.5)
mtext("No fish", side=1, line=2.5, at=3.5)
mtext(quote(delta~biomass~(mg~m^-2)), side=2, line=2.5)
