rm(list=ls())

## Model parameter estimates derived from experiments and previous work in the Hengill system
p.mat <- matrix(c(-2.762, -0.276, -4.3, -0.803, 0.271,
                  -0.911, -0.857, 0.486, -1.3988, 1.2216,
                  0.040, 0.043, 0.307, 0.081, 0.054,
                  0.829, 0.085, 0.103, 0.1148, 0.1492), ncol=2)
row.names(p.mat) <- c("logar","Er","logay2","by2","Ey2",
                      "logay3","by3","Ey3","logaM2","EM2")
colnames(p.mat) <- c("estimate", "SE")
p.minmax <- matrix(c(p.mat[,1]-1.96*p.mat[,2], p.mat[,1]+1.96*p.mat[,2]), ncol=2)

## Parameter estimates for carrying capacity from O'Gorman et al. 2017 Nature CC
logaK <- log(c(17.491, 18.082, 18.657))
EK=-0.304
logaK.12c <- logaK + EK / 8.618e-5 * (1/293.15 - 1/285.15)


p0 <- cbind(p.minmax[,1], p.mat[,1], p.minmax[,2])
p0 <- rbind(p0, logaK.12c)   #logak
p0 <- rbind(p0, c(-0.468, -0.304, 0.2))   #Ek
rownames(p0)[11:12] <- c("logaK", "EK")

p <- list(logar=p0[1,2], Er=p0[2,2], 
          logay2=p0[3,2], by2=p0[4,2], Ey2=p0[5,2],
          logay3=p0[6,2], by3=p0[7,2], Ey3=p0[8,2], 
          logaM2=p0[9,2], EM2=p0[10,2],
          logaK=p0[11,2], Ek=p0[12,2])

e2 <- 0.45
M3 <- 61.246*1000
BF <- 28.582 * 1000
Temp <- 5:25
Tarr <- (Temp-12)/8.618e-5/(Temp+273.15)/285.15


## relationship between Tarr and Temp
Temp1 <- Temp - 12
z <- lm(Tarr~Temp1)

## Supplementary Figure S10 in the paper
par(mfrow=c(1,1), mar=c(4.5,4.5,1,1))
plot(Tarr ~ Temp, xlab=expression(italic(T)~~"["*degree*C*"]"), ylab=expression(italic((T-T[0])/kTT[0])~~"[K]"), pch=20)
abline(a=-12*0.1398623,b=0.1398623, col="black")
mtext(expression(italic((T-T[0]) / kTT[0]) == 0.1399~"*"~(italic(T) - 12)), side=3, adj=0.1, line=-1.5, cex=0.8)
mtext(expression(italic(r)^2 == 0.9996), side=3, adj=0.03, line=-3, cex=0.8)


## Cascading effect versus temperature with confidence intervals
M2 <- exp(p$logaM2 + p$EM2*Tarr)
r <- exp(p$logar + p$Er*Tarr)
K <- exp(p$logaK + p$Ek*Tarr)
y2 <- exp(p$logay2 + p$by2*log(M2) + p$Ey2*Tarr)
y3 <- exp(p$logay3 + p$by3*log(M3) + p$Ey3*Tarr)

det.B1 <- y3*BF/y2/e2
det.B2 <- -r*y3*BF/e2/y2/y2/K

sim <- data.frame(Temp=Temp, det.B1=det.B1, det.B2=det.B2)


## Monte-Carlo simulation
set.seed(1)
reps <- 1000
logar <- rnorm(reps, p.mat[1,1], p.mat[1,2])
Er <- rnorm(reps, p.mat[2,1], p.mat[2,2])
logay2 <- rnorm(reps, p.mat[3,1], p.mat[3,2])
by2 <- rnorm(reps, p.mat[4,1], p.mat[4,2])
Ey2 <- rnorm(reps, p.mat[5,1], p.mat[5,2])
logay3 <- rnorm(reps, p.mat[6,1], p.mat[6,2])
by3 <- rnorm(reps, p.mat[7,1], p.mat[7,2])
Ey3 <- rnorm(reps, p.mat[8,1], p.mat[8,2])
logaM2 <- rnorm(reps, p.mat[9,1], p.mat[9,2])
EM2 <- rnorm(reps, p.mat[10,1], p.mat[10,2])
logaK <- runif(reps, p0[11,1], p0[11,3])
EK <- runif(reps, p0[12,1], p0[12,3])

detB1.MC <- matrix(NA, length(Temp), reps)
detB2.MC <- detB1.MC
for(i in 1:reps){
  M2 <- exp(logaM2[i] + EM2[i]*Tarr)
  r <- exp(logar[i] + Er[i]*Tarr)
  K <- exp(logaK[i] + EK[i]*Tarr)
  y2 <- exp(logay2[i] + by2[i]*log(M2) + Ey2[i]*Tarr)
  y3 <- exp(logay3[i] + by3[i]*log(M3) + Ey3[i]*Tarr)
  
  detB1.MC[,i] <- y3*BF/y2/e2
  detB2.MC[,i] <- -r*y3*BF/e2/y2/y2/K
}


## Get confidence intervals
for(i in 1:nrow(sim)){
  tmp1 <- detB1.MC[i,]
  CI1 <- quantile(log(tmp1), c(0.025, 0.975))
  sim$detB1.LB[i] <- exp(CI1[1])
  sim$detB1.UB[i] <- exp(CI1[2])
  
  tmp2 <- detB2.MC[i,]
  CI2 <- quantile(log(-tmp2), c(0.025, 0.975))
  sim$detB2.LB[i] <- -exp(CI2[1])
  sim$detB2.UB[i] <- -exp(CI2[2])
}


## With log-transformation
sim.ts <- sim
sim.ts$det.B1 <- log(sim$det.B1)
sim.ts$det.B2 <- -log(-sim$det.B2)
sim.ts$detB1.LB <- log(sim$detB1.LB)
sim.ts$detB1.UB <- log(sim$detB1.UB)
sim.ts$detB2.LB <- -log(-sim$detB2.LB)
sim.ts$detB2.UB <- -log(-sim$detB2.UB)


## Components in the cold streams for invertebrates
est.cold2 <- c(-p.mat[1,1],5*0.1399*p.mat[2,1],2*p.mat[3,1],2*p.mat[4,1]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
               -10*0.1399*p.mat[5,1], -p.mat[6,1], -p.mat[7,1]*log(M3), 5*0.1399*p.mat[8,1],
               2*p.mat[9,1]*p.mat[4,1], -10*0.1399*p.mat[10,1]*p.mat[4,1],
               p0[11,2], -5*0.1399*p0[12,2])
lb.cold2 <- est.cold2[1:10]-1.96*c(p.mat[1,2],5*0.1399*p.mat[2,2],2*p.mat[3,2],2*p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   10*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   2*p.mat[9,2]*p.mat[4,1], 10*0.1399*p.mat[10,2]*p.mat[4,1])
lb.cold2 <- c(lb.cold2, p0[11,1], -5*0.1399*p0[12,3])

ub.cold2 <- est.cold2[1:10]+1.96*c(p.mat[1,2],5*0.1399*p.mat[2,2],2*p.mat[3,2],2*p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   10*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   2*p.mat[9,2]*p.mat[4,1], 10*0.1399*p.mat[10,2]*p.mat[4,1])
ub.cold2 <- c(ub.cold2, p0[11,3], -5*0.1399*p0[12,1])

## Components in the warm streams for invertebrates
est.warm2 <- c(-p.mat[1,1],-5*0.1399*p.mat[2,1],2*p.mat[3,1],2*p.mat[4,1]*(p.mat[9,1]+5*0.1399*p.mat[10,1]),
               10*0.1399*p.mat[5,1], -p.mat[6,1], -p.mat[7,1]*log(M3), -5*0.1399*p.mat[8,1],
               2*p.mat[9,1]*p.mat[4,1], 10*0.1399*p.mat[10,1]*p.mat[4,1],
               p0[11,2], 5*0.1399*p0[12,2])
lb.warm2 <- est.warm2[1:10]-1.96*c(p.mat[1,2],5*0.1399*p.mat[2,2],2*p.mat[3,2],2*p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   10*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   2*p.mat[9,2]*p.mat[4,1], 10*0.1399*p.mat[10,2]*p.mat[4,1])
lb.warm2 <- c(lb.warm2, p0[11,1], 5*0.1399*p0[12,1])

ub.warm2 <- est.warm2[1:10]+1.96*c(p.mat[1,2],5*0.1399*p.mat[2,2],2*p.mat[3,2],2*p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   10*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   2*p.mat[9,2]*p.mat[4,1], 10*0.1399*p.mat[10,2]*p.mat[4,1])
ub.warm2 <- c(ub.warm2, p0[11,3], 5*0.1399*p0[12,3])


invert <- data.frame(estimate=c(est.cold2, est.warm2),
                     LB=c(lb.cold2, lb.warm2), UB=c(ub.cold2, ub.warm2),
                     type=rep(c("cold","warm"), each=12))

i.dif <- c(2,4,5,8,10,12)
cols <- rep("black", 24)
cols[i.dif] <- "dodgerblue"
cols[i.dif+12] <- "firebrick"
x.pos <- rep(1:12,2)
x.pos[i.dif] <- x.pos[i.dif] - 0.2
x.pos[i.dif+12] <- x.pos[i.dif] + 0.2
invert$col <- cols
invert$pos <- x.pos


## Components in the cold streams for diatoms
est.cold1 <- c(0,0,-p.mat[3,1],-p.mat[4,1]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
               5*0.1399*p.mat[5,1], p.mat[6,1], p.mat[7,1]*log(M3), -5*0.1399*p.mat[8,1],
               -p.mat[9,1]*p.mat[4,1], 5*0.1399*p.mat[10,1]*p.mat[4,1],
               0, 0)
lb.cold1 <- est.cold1[1:10]-1.96*c(0,0, p.mat[3,2], p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   5*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   p.mat[9,2]*p.mat[4,1], 5*0.1399*p.mat[10,2]*p.mat[4,1])
lb.cold1 <- c(lb.cold1, NA, NA)

ub.cold1 <- est.cold1[1:10]+1.96*c(0,0, p.mat[3,2], p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   5*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   p.mat[9,2]*p.mat[4,1], 5*0.1399*p.mat[10,2]*p.mat[4,1])

ub.cold1 <- c(ub.cold1, 0,0)

## Components in the warm streams for diatoms
est.warm1 <- c(0,0,-p.mat[3,1],-p.mat[4,1]*(p.mat[9,1]+5*0.1399*p.mat[10,1]),
               -5*0.1399*p.mat[5,1], p.mat[6,1], p.mat[7,1]*log(M3), 5*0.1399*p.mat[8,1],
               -p.mat[9,1]*p.mat[4,1], -5*0.1399*p.mat[10,1]*p.mat[4,1],
               0, 0)
lb.warm1 <- est.warm1[1:10]-1.96*c(0,0, p.mat[3,2], p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   5*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   p.mat[9,2]*p.mat[4,1], 5*0.1399*p.mat[10,2]*p.mat[4,1])
lb.warm1 <- c(lb.warm1, NA, NA)

ub.warm1 <- est.warm1[1:10]+1.96*c(0,0, p.mat[3,2], p.mat[4,2]*(p.mat[9,1]-5*0.1399*p.mat[10,1]),
                                   5*0.1399*p.mat[5,2], p.mat[6,2], p.mat[7,2]*log(M3), 5*0.1399*p.mat[8,2],
                                   p.mat[9,2]*p.mat[4,1], 5*0.1399*p.mat[10,2]*p.mat[4,1])
ub.warm1 <- c(ub.warm1, NA, NA)


diatom <- data.frame(estimate=c(est.cold1, est.warm1),
                     LB=c(lb.cold1, lb.warm1), UB=c(ub.cold1, ub.warm1),
                     type=rep(c("cold","warm"), each=12))

i.dif <- c(4,5,8,10)
cols <- rep("black", 24)
cols[i.dif] <- "dodgerblue"
cols[i.dif+12] <- "firebrick"
x.pos <- rep(1:12,2)
x.pos[i.dif] <- x.pos[i.dif] - 0.2
x.pos[i.dif+12] <- x.pos[i.dif] + 0.2
diatom$col <- cols
diatom$pos <- x.pos
diatom[is.na(diatom)] <- 0


## Figure 4 in the paper
tiff("Model outputs and sensitivity.tif", 16, 14, pointsize=10, units="cm", res=600, compression="lzw")
par(mfrow=c(2,2), mar=c(4.2,5,0.8,1))
plot(sim.ts$det.B2 ~ sim.ts$Temp, ylim=c(min(sim.ts$detB2.UB),max(sim.ts$detB2.LB)), pch=16,
     xlab=expression("Temperature " (degree*C)), ylab=expression(Ln~Delta~invert~biomass~(mg~m^-2)))
polygon(c(sim.ts$Temp, rev(sim.ts$Temp)), c(sim.ts$detB2.UB, rev(sim.ts$detB2.LB)), col=adjustcolor("black",alpha.f=0.25),  border = NA)
lines(range(sim.ts$Temp),rev(range(sim.ts$det.B2)))
mtext("a", side=3, line=-0.5, adj=-0.25, font=2, cex=1.2)

plot(invert$estimate ~ invert$pos, pch=16, col=invert$col, ylim=c(min(invert$LB),max(invert$UB)),
     xaxt="n", xlab="Model parameter", ylab="")
mtext("Effect of parameter on", side=2, line=4, cex=0.8)
mtext(expression(Ln~Delta~invert~biomass~(mg~m^-2)), side=2, line=2.5, cex=0.8)
abline(0,0, col="grey")
arrows(invert$pos, invert$LB, invert$pos, invert$UB, code=3, angle=90, length=0.05, col=invert$col)
text(c(1:12), (min(invert$LB)-(diff(c(min(invert$LB),max(invert$UB)))/10)), srt=45, adj=1, xpd=T,
     lab=c(expression(ln~italic(a[r])), expression(italic(E[r])), expression(ln~italic(a[y2])),
           expression(italic(b[y2])), expression(italic(E[y2])), expression(ln~italic(a[y3])),
           expression(italic(b[y3])), expression(italic(E[y3])), expression(ln~italic(a[M2])),
           expression(italic(E[M2])), expression(ln~italic(a[K])), expression(italic(E[K]))))
mtext("b", side=3, line=-0.5, adj=-0.25, font=2, cex=1.2)

plot(sim.ts$det.B1 ~ sim.ts$Temp, ylim=c(min(sim.ts$detB1.LB),max(sim.ts$detB1.UB)), pch=16,
     xlab=expression("Temperature " (degree*C)), ylab=expression(Ln~Delta~diatom~biomass~(mg~m^-2)))
polygon(c(sim.ts$Temp, rev(sim.ts$Temp)), c(sim.ts$detB1.UB, rev(sim.ts$detB1.LB)), col=adjustcolor("black",alpha.f=0.25),  border = NA)
lines(range(sim.ts$Temp),range(sim.ts$det.B1))
mtext("c", side=3, line=-0.5, adj=-0.25, font=2, cex=1.2)

plot(diatom$estimate ~ diatom$pos, pch=16, col=diatom$col, ylim=c(min(diatom$LB),max(diatom$UB)),
     xaxt="n", xlab="Model parameter", ylab="")
mtext("Effect of parameter on", side=2, line=4, cex=0.8)
mtext(expression(Ln~Delta~diatom~biomass~(mg~m^-2)), side=2, line=2.5, cex=0.8)
abline(0,0, col="grey")
arrows(diatom$pos, diatom$LB, diatom$pos, diatom$UB, code=3, angle=90, length=0.05, col=diatom$col)
text(c(1:12), (min(diatom$LB)-(diff(c(min(diatom$LB),max(diatom$UB)))/10)), srt=45, adj=1, xpd=T,
     lab=c(expression(ln~italic(a[r])), expression(italic(E[r])), expression(ln~italic(a[y2])),
           expression(italic(b[y2])), expression(italic(E[y2])), expression(ln~italic(a[y3])),
           expression(italic(b[y3])), expression(italic(E[y3])), expression(ln~italic(a[M2])),
           expression(italic(E[M2])), expression(ln~italic(a[K])), expression(italic(E[K]))))
mtext("d", side=3, line=-0.5, adj=-0.25, font=2, cex=1.2)
dev.off()


## Sensitivity analysis figures
res.sens <- vector("list", length(p))
names(res.sens) <- names(p)

for(i in 1:length(p)){
  types <- c("min", "estimated", "max")
  
  res1 <- data.frame(parameter=rep(NA, length(Tarr)*3), type=rep(NA, length(Tarr)*3), 
                     Temp=rep(NA, length(Tarr)*3),
                     detB1=rep(NA, length(Tarr)*3), detB2=rep(NA, length(Tarr)*3))
  
  for(j in 1:3){
    p1 <- p
    p1[[i]] <- p0[i,j]
    
    M2 <- exp(p1$logaM2 + p1$EM2*Tarr)
    r <- exp(p1$logar + p1$Er*Tarr)
    K <- exp(p1$logaK + p1$Ek*Tarr)
    y2 <- exp(p1$logay2 + p1$by2*log(M2) + p1$Ey2*Tarr)
    y3 <- exp(p1$logay3 + p1$by3*log(M3) + p1$Ey3*Tarr)
    
    det.B1 <- y3*BF/y2/e2
    det.B2 <- -r*y3*BF/e2/y2/y2/K
    
    a1 <- (length(Tarr) * (j-1) + 1):(length(Tarr)*j)
    res1$parameter[a1] <- p1[[i]]
    res1$type[a1] <- types[j]
    res1$Temp[a1] <- Temp
    res1$detB1[a1] <- det.B1
    res1$detB2[a1] <- det.B2
  }
  
  res.sens[[i]] <- res1
}


par1 <- list(logar="ln ", Er="", logay2="ln ", by2="", Ey2="", logay3="ln ", by3="", Ey3="", logaM2="ln ", EM2="", logaK="ln ", EK="")
par2 <- list(logar="a", Er="E", logay2="a", by2="b", Ey2="E", logay3="a", by3="b", Ey3="E", logaM2="a", EM2="E", logaK="a", EK="E")
par3 <- list(logar="r",Er="r", logay2="y2", by2="y2", Ey2="y2", logay3="y3", by3="y3", Ey3="y3", logaM2="M2", EM2="M2", logaK="K", EK="K")

## Supplementary Figure S8 in the paper
tiff("Sensitivity of invert biomass.tif", 13, 16, pointsize=9, units="cm", res=600, compression="lzw")
par(mfrow=c(4,3), mar=c(2,2,1,1), oma=c(4,4,0,0), mgp=c(3,1,0))
for(i in 1:length(res.sens)){
  dd <- res.sens[[i]]
  dd$detB2 <- -log(-dd$detB2)
  
  plot(detB2~Temp, data=dd[dd$type=="estimated",], type="o",  ylim=range(dd$detB2), xlab=NA, ylab=NA, lwd=1.5, cex.axis=1.2)
  lines(detB2~Temp, data=dd[dd$type=="min", ], type="o", col="dodgerblue")
  lines(detB2~Temp, data=dd[dd$type=="max", ], type="o", col="firebrick")
  mtext(bquote(bold("("*.(letters[i])*")")~.(par1[[i]])*italic(.(par2[[i]]) [.(par3[[i]])])), side=3, line=-2, adj=0.95)
  legend("bottomleft", legend=format(round(unique(dd$parameter),3),nsmall=3), lty="solid", col=c("dodgerblue","black","firebrick"))
}
mtext(expression(Delta~invert~biomass~(mg~m^-2)), side=2, line=1.5, cex.lab=2, adj=0.52, outer=T)
mtext(expression("Temperature " (degree*C)), side=1, line=2, cex.lab=2, adj=0.52, outer=T) 
dev.off()

## Supplementary Figure S9 in the paper
tiff("Sensitivity of diatom biomass.tif", 13, 16, pointsize=9, units="cm", res=600, compression="lzw")
par(mfrow=c(4,3), mar=c(2,2,1,1), oma=c(4,4,0,0), mgp=c(3,1,0))
for(i in 1:length(res.sens)){
  dd <- res.sens[[i]]
  dd$detB1 <- log(dd$detB1)
  plot(detB1 ~ Temp, data=dd[dd$type=="estimated",], type="o", ylim=range(dd$detB1), xlab=NA, ylab=NA, lwd=1.5, cex.axis=1.2)
  lines(detB1 ~ Temp, data=dd[dd$type=="min",], type="o", col="dodgerblue")
  lines(detB1 ~ Temp, data=dd[dd$type=="max",], type="o", col="firebrick")
  mtext(bquote(bold("("*.(letters[i])*")")~.(par1[[i]])*italic(.(par2[[i]]) [.(par3[[i]])])), side=3, line=-2, adj=0.02)
  legend("bottomright", legend=format(round(unique(dd$parameter),3),nsmall=3), lty="solid", col=c("dodgerblue","black","firebrick"))
}
mtext(expression(Delta~diatom~biomass~(mg~m^-2)), side=2, line=1.5, cex.lab=2, adj=0.52, outer=T)
mtext(expression("Temperature " (degree*C)), side=1, line=2, cex.lab=2, adj=0.52, outer=T) 
dev.off()
